@@ -54,6 +54,25 @@
 #include "xfce-backdrop.h" /* for XfceBackdropImageStyle */
 
 
+gint
+xfdesktop_compare_paths(GFile *a, GFile *b)
+{
+    gchar *path_a, *path_b;
+    gboolean ret;
+
+    path_a = g_file_get_path(a);
+    path_b = g_file_get_path(b);
+
+    DBG("a %s, b %s", path_a, path_b);
+
+    ret = g_strcmp0(path_a, path_b);
+
+    g_free(path_a);
+    g_free(path_b);
+
+    return ret;
+}
+
 gchar *
 xfdesktop_get_file_mimetype(const gchar *file)
 {
@@ -173,3 +192,42 @@ xfdesktop_popup_keyboard_grab_available(GdkWindow *win)
 
     return timestamp;
 }
+
+
+#ifdef G_ENABLE_DEBUG
+/* With --enable-debug=full turn on debugging messages from the start */
+static gboolean enable_debug = TRUE;
+#else
+static gboolean enable_debug = FALSE;
+#endif /* G_ENABLE_DEBUG */
+
+#if defined(G_HAVE_ISO_VARARGS)
+void
+xfdesktop_debug(const char *func, const char *file, int line, const char *format, ...)
+{
+    va_list args;
+
+    if(!enable_debug)
+        return;
+
+    va_start(args, format);
+
+    fprintf(stdout, "DBG[%s:%d] %s(): ", file, line, func);
+    vfprintf(stdout, format, args);
+    fprintf(stdout, "\n");
+
+    va_end(args);
+}
+#endif /* defined(G_HAVE_ISO_VARARGS) */
+
+/**
+ * xfdesktop_debug_set:
+ * debug: TRUE to turn on the XF_DEBUG mesages.
+ */
+void
+xfdesktop_debug_set(gboolean debug)
+{
+    enable_debug = debug;
+    if(enable_debug)
+        XF_DEBUG("debugging enabled");
+}
