@@ -221,7 +221,7 @@ xfdesktop_thumbnailer_dispose(GObject *object)
             g_object_unref(thumbnailer->priv->proxy);
 
         if(thumbnailer->priv->supported_mimetypes)
-            g_free(thumbnailer->priv->supported_mimetypes);
+            g_strfreev(thumbnailer->priv->supported_mimetypes);
 
         g_free(thumbnailer->priv);
         thumbnailer->priv = NULL;
@@ -281,7 +281,7 @@ xfdesktop_thumbnailer_is_supported(XfdesktopThumbnailer *thumbnailer,
     mime_type = xfdesktop_get_file_mimetype(file);
 
     if(mime_type == NULL) {
-        DBG("File %s has no mime type", file);
+        XF_DEBUG("File %s has no mime type", file);
         return FALSE;
     }
 
@@ -315,7 +315,7 @@ xfdesktop_thumbnailer_queue_thumbnail(XfdesktopThumbnailer *thumbnailer,
     g_return_val_if_fail(file != NULL, FALSE);
 
     if(!xfdesktop_thumbnailer_is_supported(thumbnailer, file)) {
-        DBG("file: %s not supported", file);
+        XF_DEBUG("file: %s not supported", file);
         return FALSE;
     }
     if(thumbnailer->priv->request_timer_id) {
@@ -565,11 +565,13 @@ xfdesktop_thumbnailer_thumbnail_ready_dbus(DBusGProxy *proxy,
                 (char*)iter->data,
                 thumbnail_location);
 
-            g_signal_emit(G_OBJECT(thumbnailer),
-                          thumbnailer_signals[THUMBNAIL_READY],
-                          0,
-                          iter->data,
-                          thumbnail_location);
+            if(g_file_test(thumbnail_location, G_FILE_TEST_EXISTS)) {
+                g_signal_emit(G_OBJECT(thumbnailer),
+                              thumbnailer_signals[THUMBNAIL_READY],
+                              0,
+                              iter->data,
+                              thumbnail_location);
+            }
 
             temp = iter->data;
             thumbnailer->priv->queue = g_slist_remove(thumbnailer->priv->queue,
