@@ -1264,8 +1264,9 @@ xfdesktop_settings_background_tab_change_bindings(AppearancePanel *panel,
             gint image_style;
             old_property = xfdesktop_settings_generate_old_binding_string(panel, "image-style");
 
-            /* default to stretched when trying to migrate */
-            image_style = xfconf_channel_get_int(channel, old_property, XFCE_BACKDROP_IMAGE_STRETCHED);
+            /* default to zoomed when trying to migrate (zoomed was part of how
+             * auto worked in 4.10)*/
+            image_style = xfconf_channel_get_int(channel, old_property, XFCE_BACKDROP_IMAGE_ZOOMED);
 
             /* xfce_translate_image_styles will do sanity checking */
             gtk_combo_box_set_active(GTK_COMBO_BOX(panel->image_style_combo),
@@ -1688,7 +1689,8 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
     GtkWidget *appearance_container, *chk_custom_font_size,
               *spin_font_size, *w, *box, *spin_icon_size,
               *chk_show_thumbnails, *chk_single_click, *appearance_settings,
-              *chk_show_tooltips, *spin_tooltip_size, *bnt_exit, *content_area;
+              *chk_show_tooltips, *spin_tooltip_size, *bnt_exit, *content_area,
+              *chk_show_hidden_files;
     GtkBuilder *appearance_gxml;
     GError *error = NULL;
     GtkFileFilter *filter;
@@ -1729,6 +1731,10 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
     chk_single_click = GTK_WIDGET(gtk_builder_get_object(main_gxml,
                                                          "chk_single_click"));
 
+    /* show hidden files */
+    chk_show_hidden_files = GTK_WIDGET(gtk_builder_get_object(main_gxml,
+                                                              "chk_show_hidden_files"));
+
     /* tooltip options */
     chk_show_tooltips = GTK_WIDGET(gtk_builder_get_object(main_gxml, "chk_show_tooltips"));
     spin_tooltip_size = GTK_WIDGET(gtk_builder_get_object(main_gxml, "spin_tooltip_size"));
@@ -1847,7 +1853,7 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
                      panel);
 
     /* Pick the first entries so something shows up */
-    gtk_combo_box_set_active(GTK_COMBO_BOX(panel->image_style_combo), XFCE_BACKDROP_IMAGE_STRETCHED);
+    gtk_combo_box_set_active(GTK_COMBO_BOX(panel->image_style_combo), XFCE_BACKDROP_IMAGE_ZOOMED);
     gtk_combo_box_set_active(GTK_COMBO_BOX(panel->color_style_combo), XFCE_BACKDROP_COLOR_SOLID);
 
     /* Use these settings for all workspaces checkbox */
@@ -1956,6 +1962,9 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
     xfconf_g_property_bind(channel, DESKTOP_ICONS_TOOLTIP_SIZE_PROP, G_TYPE_DOUBLE,
                            G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(spin_tooltip_size))),
                            "value");
+    xfconf_g_property_bind(channel, DESKTOP_ICONS_SHOW_HIDDEN_FILES,
+                           G_TYPE_BOOLEAN, G_OBJECT(chk_show_hidden_files),
+                           "active");
     xfconf_g_property_bind(channel, DESKTOP_ICONS_SHOW_THUMBNAILS,
                            G_TYPE_BOOLEAN, G_OBJECT(chk_show_thumbnails),
                            "active");
@@ -2110,6 +2119,13 @@ main(int argc, char **argv)
         wnck_screen = wnck_screen_get(screen);
         wnck_screen_force_update(wnck_screen);
         panel->wnck_window = wnck_screen_get_active_window(wnck_screen);
+
+        /* These callbacks are for updating the image_iconview when the window
+         * moves to another monitor or workspace */
+        g_signal_connect(panel->wnck_window, "geometry-changed",
+                         G_CALLBACK(cb_update_background_tab), panel);
+        g_signal_connect(panel->wnck_window, "workspace-changed",
+                         G_CALLBACK(cb_update_background_tab), panel);
     }
 
     panel->channel = channel;
