@@ -174,6 +174,11 @@ static void xfce_desktop_set_single_workspace_number(XfceDesktop *desktop,
 static gboolean xfce_desktop_get_single_workspace_mode(XfceDesktop *desktop);
 static gint xfce_desktop_get_current_workspace(XfceDesktop *desktop);
 
+#ifdef ENABLE_DESKTOP_ICONS
+static void hidden_state_changed_cb(GObject *object, XfceDesktop *desktop);
+#endif
+
+
 static guint signals[N_SIGNALS] = { 0, };
 
 /* private functions */
@@ -199,7 +204,7 @@ xfce_desktop_ensure_system_font_size(XfceDesktop *desktop)
         DBG("dividing by PANGO_SCALE");
         desktop->priv->system_font_size /= PANGO_SCALE;
     }
-    DBG("system font size is %.05f", desktop->priv->system_font_size);
+    XF_DEBUG("system font size is %.05f", desktop->priv->system_font_size);
     
     g_free(font_name);
     pango_font_description_free(pfd);
@@ -258,6 +263,8 @@ xfce_desktop_setup_icon_view(XfceDesktop *desktop)
         }
         gtk_widget_show(desktop->priv->icon_view);
         gtk_container_add(GTK_CONTAINER(desktop), desktop->priv->icon_view);
+
+        g_signal_connect(G_OBJECT(manager), "hidden-state-changed", G_CALLBACK(hidden_state_changed_cb), desktop);
     }
     
     gtk_widget_queue_draw(GTK_WIDGET(desktop));
@@ -391,7 +398,7 @@ backdrop_changed_cb(XfceBackdrop *backdrop, gpointer user_data)
 #ifdef G_ENABLE_DEBUG
     monitor_name = gdk_screen_get_monitor_plug_name(gscreen, monitor);
 
-    DBG("backdrop changed for workspace %d, monitor %d (%s)", current_workspace, monitor, monitor_name);
+    XF_DEBUG("backdrop changed for workspace %d, monitor %d (%s)", current_workspace, monitor, monitor_name);
 
     g_free(monitor_name);
 #endif
@@ -416,12 +423,12 @@ backdrop_changed_cb(XfceBackdrop *backdrop, gpointer user_data)
 
         rect.width = gdk_screen_get_width(gscreen);
         rect.height = gdk_screen_get_height(gscreen);
-        DBG("xinerama_stretch x %d, y %d, width %d, height %d",
-            rect.x, rect.y, rect.width, rect.height);
+        XF_DEBUG("xinerama_stretch x %d, y %d, width %d, height %d",
+                 rect.x, rect.y, rect.width, rect.height);
     } else {
         gdk_screen_get_monitor_geometry(gscreen, monitor, &rect);
-        DBG("monitor x %d, y %d, width %d, height %d",
-            rect.x, rect.y, rect.width, rect.height);
+        XF_DEBUG("monitor x %d, y %d, width %d, height %d",
+                 rect.x, rect.y, rect.width, rect.height);
     }
 
     xfce_backdrop_set_size(backdrop, rect.width, rect.height);
@@ -430,8 +437,8 @@ backdrop_changed_cb(XfceBackdrop *backdrop, gpointer user_data)
        && !xfce_workspace_get_xinerama_stretch(desktop->priv->workspaces[current_workspace])) {
         clip_region = gdk_region_rectangle(&rect);
 
-        DBG("clip_region: x: %d, y: %d, w: %d, h: %d",
-            rect.x, rect.y, rect.width, rect.height);
+        XF_DEBUG("clip_region: x: %d, y: %d, w: %d, h: %d",
+                 rect.x, rect.y, rect.width, rect.height);
 
         /* If we are not monitor 0 on a multi-monitor setup we need to subtract
          * all the previous monitor regions so we don't draw over them. This
@@ -442,9 +449,9 @@ backdrop_changed_cb(XfceBackdrop *backdrop, gpointer user_data)
             GdkRegion *previous_region;
             gdk_screen_get_monitor_geometry(gscreen, i, &previous_monitor);
 
-            DBG("previous_monitor: x: %d, y: %d, w: %d, h: %d",
-                previous_monitor.x, previous_monitor.y,
-                previous_monitor.width, previous_monitor.height);
+            XF_DEBUG("previous_monitor: x: %d, y: %d, w: %d, h: %d",
+                     previous_monitor.x, previous_monitor.y,
+                     previous_monitor.width, previous_monitor.height);
 
             previous_region = gdk_region_rectangle(&previous_monitor);
 
@@ -457,8 +464,8 @@ backdrop_changed_cb(XfceBackdrop *backdrop, gpointer user_data)
     if(clip_region != NULL) {
         /* Update the area to redraw to limit the icons/area painted */
         gdk_region_get_clipbox(clip_region, &rect);
-        DBG("area to update: x: %d, y: %d, w: %d, h: %d",
-            rect.x, rect.y, rect.width, rect.height);
+        XF_DEBUG("area to update: x: %d, y: %d, w: %d, h: %d",
+                 rect.x, rect.y, rect.width, rect.height);
     }
 
     if(rect.width != 0 && rect.height != 0) {
@@ -607,15 +614,10 @@ workspace_changed_cb(WnckScreen *wnck_screen,
 {
     XfceDesktop *desktop = XFCE_DESKTOP(user_data);
     gint current_workspace, new_workspace, i;
-    XfceBackdrop *current_backdrop, *new_backdrop;
+    XfceBackdrop *backdrop;
 
     TRACE("entering");
 
-    /* Ignore workspace changes in single workspace mode so long as we
-     * already have the bg_pixmap loaded */
-    if(xfce_desktop_get_single_workspace_mode(desktop) && desktop->priv->bg_pixmap)
-        return;
-
     current_workspace = desktop->priv->current_workspace;
     new_workspace = xfce_desktop_get_current_workspace(desktop);
 
@@ -624,26 +626,13 @@ workspace_changed_cb(WnckScreen *wnck_screen,
 
     desktop->priv->current_workspace = new_workspace;
 
-    DBG("current_workspace %d, new_workspace %d",
-        current_workspace, new_workspace);
+    XF_DEBUG("current_workspace %d, new_workspace %d",
+             current_workspace, new_workspace);
 
     for(i = 0; i < xfce_desktop_get_n_monitors(desktop); i++) {
-        /* We want to compare the current workspace backdrop with the new one
-         * and see if we can avoid changing them if they are the same image/style */
-        if(current_workspace < desktop->priv->nworkspaces && current_workspace >= 0) {
-            current_backdrop = xfce_workspace_get_backdrop(desktop->priv->workspaces[current_workspace], i);
-            new_backdrop = xfce_workspace_get_backdrop(desktop->priv->workspaces[new_workspace], i);
-
-            if(!xfce_backdrop_compare_backdrops(current_backdrop, new_backdrop) || !desktop->priv->bg_pixmap) {
-                /* only update monitors that require it */
-                backdrop_changed_cb(new_backdrop, user_data);
-            }
-        } else {
-            /* If current_workspace was removed or never existed, get the new
-             * backdrop and apply it */
-            new_backdrop = xfce_workspace_get_backdrop(desktop->priv->workspaces[new_workspace], i);
-            backdrop_changed_cb(new_backdrop, user_data);
-        }
+        backdrop = xfce_workspace_get_backdrop(desktop->priv->workspaces[new_workspace], i);
+        /* update it */
+        backdrop_changed_cb(backdrop, user_data);
 
         /* When we're spanning screens we only care about the first monitor */
         if(xfce_workspace_get_xinerama_stretch(desktop->priv->workspaces[new_workspace]))
@@ -675,10 +664,6 @@ workspace_created_cb(WnckScreen *wnck_screen,
                                                                     desktop->priv->property_prefix,
                                                                     nlast_workspace);
 
-    /* Tell workspace whether to cache pixbufs */
-    xfce_workspace_set_cache_pixbufs(desktop->priv->workspaces[nlast_workspace],
-                                     !desktop->priv->single_workspace_mode);
-
     xfce_workspace_monitors_changed(desktop->priv->workspaces[nlast_workspace],
                                     desktop->priv->gscreen);
 
@@ -899,8 +884,10 @@ xfce_desktop_finalize(GObject *object)
     g_object_unref(G_OBJECT(desktop->priv->channel));
     g_free(desktop->priv->property_prefix);
 
+#ifdef ENABLE_DESKTOP_ICONS
     if(desktop->priv->style_refresh_timer != 0)
         g_source_remove(desktop->priv->style_refresh_timer);
+#endif
 
     G_OBJECT_CLASS(xfce_desktop_parent_class)->finalize(object);
 }
@@ -1259,13 +1246,12 @@ xfce_desktop_delete_event(GtkWidget *w,
     return TRUE;
 }
 
+#ifdef ENABLE_DESKTOP_ICONS
 static gboolean
 style_refresh_cb(gpointer *w)
 {
     XfceDesktop *desktop = XFCE_DESKTOP(w);
-#ifdef ENABLE_DESKTOP_ICONS
     gdouble old_font_size;
-#endif
 
     TRACE("entering");
 
@@ -1284,7 +1270,6 @@ style_refresh_cb(gpointer *w)
 
     gtk_widget_queue_draw(GTK_WIDGET(desktop));
 
-#ifdef ENABLE_DESKTOP_ICONS
     if(!desktop->priv->icon_view || !XFDESKTOP_IS_ICON_VIEW(desktop->priv->icon_view))
         return FALSE;
 
@@ -1299,14 +1284,15 @@ style_refresh_cb(gpointer *w)
         xfdesktop_icon_view_set_font_size(XFDESKTOP_ICON_VIEW(desktop->priv->icon_view),
                                           desktop->priv->system_font_size);
     }
-#endif
 
     return FALSE;
 }
+#endif
 
 static void
 xfce_desktop_style_set(GtkWidget *w, GtkStyle *old_style)
 {
+#ifdef ENABLE_DESKTOP_ICONS
     XfceDesktop *desktop = XFCE_DESKTOP(w);
 
     TRACE("entering");
@@ -1318,8 +1304,7 @@ xfce_desktop_style_set(GtkWidget *w, GtkStyle *old_style)
                                                          (GSourceFunc)style_refresh_cb,
                                                          w,
                                                          NULL);
-
-    GTK_WIDGET_CLASS(xfce_desktop_parent_class)->style_set(w, old_style);
+#endif
 }
 
 static void
@@ -1380,9 +1365,9 @@ xfce_desktop_get_current_workspace(XfceDesktop *desktop)
         current_workspace = workspace_num;
     }
 
-    DBG("workspace_num %d, single_workspace_num %d, current_workspace %d, max workspaces %d",
-        workspace_num, desktop->priv->single_workspace_num, current_workspace,
-        desktop->priv->nworkspaces);
+    XF_DEBUG("workspace_num %d, single_workspace_num %d, current_workspace %d, max workspaces %d",
+             workspace_num, desktop->priv->single_workspace_num, current_workspace,
+             desktop->priv->nworkspaces);
 
     return current_workspace;
 }
@@ -1470,6 +1455,46 @@ xfce_desktop_set_icon_style(XfceDesktop *desktop,
 #endif
 }
 
+#ifdef ENABLE_DESKTOP_ICONS
+static gboolean
+hidden_idle_cb(gpointer user_data)
+{
+    XfceDesktop *desktop;
+
+    g_return_val_if_fail(XFCE_IS_DESKTOP(user_data), FALSE);
+
+    desktop = XFCE_DESKTOP(user_data);
+
+    /* destroy and load the icon view so that it adds or removes
+     * the hidden icons from the desktop */
+    if(desktop->priv->icon_view) {
+        gtk_widget_destroy(desktop->priv->icon_view);
+        desktop->priv->icon_view = NULL;
+    }
+
+    if(gtk_widget_get_realized(GTK_WIDGET(desktop)))
+        xfce_desktop_setup_icon_view(desktop);
+
+    return FALSE;
+}
+
+static void
+hidden_state_changed_cb(GObject *object,
+                        XfceDesktop *desktop)
+{
+    g_return_if_fail(XFCE_IS_DESKTOP(desktop));
+
+    if(desktop->priv->icon_view) {
+        g_signal_handlers_disconnect_by_func(object,
+                                             G_CALLBACK(hidden_state_changed_cb),
+                                             desktop);
+    }
+
+    /* We have to do this in an idle callback */
+    g_idle_add(hidden_idle_cb, desktop);
+}
+#endif /* ENABLE_DESKTOP_ICONS */
+
 XfceDesktopIconStyle
 xfce_desktop_get_icon_style(XfceDesktop *desktop)
 {
@@ -1549,8 +1574,6 @@ static void
 xfce_desktop_set_single_workspace_mode(XfceDesktop *desktop,
                                        gboolean single_workspace)
 {
-    gint i;
-
     g_return_if_fail(XFCE_IS_DESKTOP(desktop));
 
     if(single_workspace == desktop->priv->single_workspace_mode)
@@ -1560,13 +1583,6 @@ xfce_desktop_set_single_workspace_mode(XfceDesktop *desktop,
 
     DBG("single_workspace_mode now %s", single_workspace ? "TRUE" : "FALSE");
 
-    /* update the workspaces & backdrops if they should cache their pixbuf */
-    if(desktop->priv->workspaces) {
-        for(i = 0; i < desktop->priv->nworkspaces; i++) {
-            /* set cache to TRUE when single_workspace is FALSE */
-            xfce_workspace_set_cache_pixbufs(desktop->priv->workspaces[i], !single_workspace);
-        }
-    }
 
     /* If the desktop has been realized then fake a screen size change to
      * update the backdrop. There's no reason to if there's no desktop yet */
@@ -1699,8 +1715,9 @@ xfce_desktop_popup_secondary_root_menu(XfceDesktop *desktop,
     xfce_desktop_do_menu_popup(desktop, button, activate_time,
                                signals[SIG_POPULATE_SECONDARY_ROOT_MENU]);
 }
+
 void
-xfce_desktop_refresh(XfceDesktop *desktop)
+xfce_desktop_refresh(XfceDesktop *desktop, gboolean advance_wallpaper)
 {
     gint i, current_workspace;
 
@@ -1723,9 +1740,19 @@ xfce_desktop_refresh(XfceDesktop *desktop)
 
         backdrop = xfce_workspace_get_backdrop(desktop->priv->workspaces[current_workspace], i);
 
-        backdrop_changed_cb(backdrop, desktop);
+        if(advance_wallpaper) {
+            /* We need to trigger a new wallpaper event */
+            xfce_backdrop_force_cycle(backdrop);
+        } else {
+            /* Fake a changed event so we redraw the wallpaper */
+            backdrop_changed_cb(backdrop, desktop);
+        }
     }
 
+    /* If we're only advancing the wallpaper we can exit here */
+    if(advance_wallpaper)
+        return;
+
 #ifdef ENABLE_DESKTOP_ICONS
     /* reload icon view */
     if(desktop->priv->icon_view) {
