@@ -79,11 +79,11 @@ static void xfdesktop_regular_file_icon_delete_thumbnail_file(XfdesktopIcon *ico
 
 static GdkPixbuf *xfdesktop_regular_file_icon_peek_pixbuf(XfdesktopIcon *icon,
                                                           gint width, gint height);
-static G_CONST_RETURN gchar *xfdesktop_regular_file_icon_peek_label(XfdesktopIcon *icon);
+static const gchar *xfdesktop_regular_file_icon_peek_label(XfdesktopIcon *icon);
 static gchar *xfdesktop_regular_file_icon_get_identifier(XfdesktopIcon *icon);
 static GdkPixbuf *xfdesktop_regular_file_icon_peek_tooltip_pixbuf(XfdesktopIcon *icon,
                                                                   gint width, gint height);
-static G_CONST_RETURN gchar *xfdesktop_regular_file_icon_peek_tooltip(XfdesktopIcon *icon);
+static const gchar *xfdesktop_regular_file_icon_peek_tooltip(XfdesktopIcon *icon);
 static GdkDragAction xfdesktop_regular_file_icon_get_allowed_drag_actions(XfdesktopIcon *icon);
 static GdkDragAction xfdesktop_regular_file_icon_get_allowed_drop_actions(XfdesktopIcon *icon,
                                                                           GdkDragAction *suggested_action);
@@ -367,6 +367,7 @@ xfdesktop_load_icon_from_desktop_file(XfdesktopRegularFileIcon *regular_icon)
     gchar *contents;
     gsize length;
     GIcon *gicon = NULL;
+    gchar *p;
 
     /* try to load the file into memory */
     if(g_file_load_contents(regular_icon->priv->file, NULL, &contents, &length,
@@ -388,6 +389,12 @@ xfdesktop_load_icon_from_desktop_file(XfdesktopRegularFileIcon *regular_icon)
                 /* icon_name is an absolute path, create it as a file icon */
                 gicon = g_file_icon_new(g_file_new_for_path(icon_name));
             } else if(icon_name) {
+                /* drop any suffix (e.g. '.png') from themed icons */
+                if (!g_path_is_absolute (icon_name)) {
+                    p = strrchr (icon_name, '.');
+                    if (p != NULL)
+                        *p = '\0';
+                }
                 /* otherwise create a themed icon for it */
                 gicon = g_themed_icon_new(icon_name);
             }
@@ -525,7 +532,7 @@ xfdesktop_regular_file_icon_peek_tooltip_pixbuf(XfdesktopIcon *icon,
     return tooltip_pix;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 xfdesktop_regular_file_icon_peek_label(XfdesktopIcon *icon)
 {
     XfdesktopRegularFileIcon *regular_file_icon = XFDESKTOP_REGULAR_FILE_ICON(icon);
@@ -697,7 +704,7 @@ xfdesktop_regular_file_icon_do_drop_dest(XfdesktopIcon *icon,
     return result;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 xfdesktop_regular_file_icon_peek_tooltip(XfdesktopIcon *icon)
 {
     XfdesktopRegularFileIcon *regular_file_icon = XFDESKTOP_REGULAR_FILE_ICON(icon);
